Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'io_scene_gltf2')
-rwxr-xr-xio_scene_gltf2/__init__.py2
-rw-r--r--io_scene_gltf2/blender/com/gltf2_blender_ui.py4
-rwxr-xr-xio_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py2
-rwxr-xr-xio_scene_gltf2/blender/exp/gltf2_blender_gather_primitive_attributes.py7
-rwxr-xr-xio_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py4
5 files changed, 13 insertions, 6 deletions
diff --git a/io_scene_gltf2/__init__.py b/io_scene_gltf2/__init__.py
index ee60f4aa..ecc5a499 100755
--- a/io_scene_gltf2/__init__.py
+++ b/io_scene_gltf2/__init__.py
@@ -4,7 +4,7 @@
bl_info = {
'name': 'glTF 2.0 format',
'author': 'Julien Duroure, Scurest, Norbert Nopper, Urs Hanselmann, Moritz Becher, Benjamin Schmithüsen, Jim Eckerlein, and many external contributors',
- "version": (3, 3, 26),
+ "version": (3, 4, 9),
'blender': (3, 3, 0),
'location': 'File > Import-Export',
'description': 'Import-Export as glTF 2.0',
diff --git a/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py b/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py
index ba331b74..53d78945 100755
--- a/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py
+++ b/io_scene_gltf2/blender/exp/gltf2_blender_gather_animation_sampler_keyframes.py
@@ -405,7 +405,7 @@ def gather_keyframes(blender_obj_uuid: str,
# for both in and out tangents, we guarantee that (even if there are errors or numerical imprecisions)
# symmetrical control points translate to symmetrical tangents.
# Note: I am not sure that linearity is never broken with quaternions and their normalization.
- # Especially at sign swap it might occure that the value gets negated but the control point not.
+ # Especially at sign swap it might occur that the value gets negated but the control point not.
# I have however not once encountered an issue with this.
key.in_tangent = [
c.keyframe_points[i].co[1] + (c.keyframe_points[i].handle_left[1] - c.keyframe_points[i].co[1]) / (c.keyframe_points[i].handle_left[0] - c.keyframe_points[i].co[0])
diff --git a/io_scene_gltf2/blender/exp/gltf2_blender_gather_primitive_attributes.py b/io_scene_gltf2/blender/exp/gltf2_blender_gather_primitive_attributes.py
index 8572d185..1af588b9 100755
--- a/io_scene_gltf2/blender/exp/gltf2_blender_gather_primitive_attributes.py
+++ b/io_scene_gltf2/blender/exp/gltf2_blender_gather_primitive_attributes.py
@@ -173,6 +173,13 @@ def __gather_skins(blender_primitive, export_settings):
max_bone_set_index += 1
max_bone_set_index -= 1
+ # Here, a set represents a group of 4 weights.
+ # So max_bone_set_index value:
+ # if -1 => No weights
+ # if 1 => Max 4 weights
+ # if 2 => Max 8 weights
+ # etc...
+
# If no skinning
if max_bone_set_index < 0:
return attributes
diff --git a/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py b/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py
index d130f4e6..b6b8e19f 100755
--- a/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py
+++ b/io_scene_gltf2/blender/imp/gltf2_blender_pbrMetallicRoughness.py
@@ -46,7 +46,7 @@ def pbr_metallic_roughness(mh: MaterialHelper):
additional_location = 40, -370 # For occlusion and/or volume / original PBR extensions
# Set IOR to 1.5, this is the default in glTF
- # This value may be overidden later if IOR extension is set on file
+ # This value may be overridden later if IOR extension is set on file
pbr_node.inputs['IOR'].default_value = GLTF_IOR
if mh.pymat.occlusion_texture is not None or (mh.pymat.extensions and 'KHR_materials_specular' in mh.pymat.extensions):
@@ -610,7 +610,7 @@ def occlusion(mh: MaterialHelper, location, occlusion_socket):
# => [Add Emission] => [Mix Alpha] => [Material Output] if needed, only for SpecGlossiness
# => [Volume] => [Add Shader] => [Material Output] if needed
-# => [Velvet] => [Add Shader] => [Material Output] if nedded
+# => [Velvet] => [Add Shader] => [Material Output] if needed
def make_output_nodes(
mh: MaterialHelper,
location,
diff --git a/io_scene_gltf2/blender/com/gltf2_blender_ui.py b/io_scene_gltf2/blender/com/gltf2_blender_ui.py
index 128db592..0788bbbc 100644
--- a/io_scene_gltf2/blender/com/gltf2_blender_ui.py
+++ b/io_scene_gltf2/blender/com/gltf2_blender_ui.py
@@ -208,10 +208,10 @@ class SCENE_OT_gltf2_assign_to_variant(bpy.types.Operator):
return {'FINISHED'}
# Operator to reset mesh to orignal (using default material when exists)
class SCENE_OT_gltf2_reset_to_original(bpy.types.Operator):
bl_idname = "scene.gltf2_reset_to_original"
- bl_label = "Reset to Orignal"
+ bl_label = "Reset to Original"
bl_options = {'REGISTER'}
@classmethod
@@ -208,10 +208,10 @@ class SCENE_OT_gltf2_assign_to_variant(bpy.types.Operator):
return {'FINISHED'}
-# Operator to reset mesh to orignal (using default material when exists)
+# Operator to reset mesh to original (using default material when exists)
class SCENE_OT_gltf2_reset_to_original(bpy.types.Operator):
bl_idname = "scene.gltf2_reset_to_original"